# -*- coding: utf-8 -*-
# Copyright (C) 2008-2009 Jan Hülsbergen <jan@afoo.de>
#
# This file is part of cmdlib.
#
# cmdlib is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# cmdlib is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with cmdlib.  If not, see <http://www.gnu.org/licenses/>.

import os
import sys
import subprocess


class System(object):
    r'''simple interface for executing commands

    best if subclassed

    >>> s = System()
    >>> s.do("ls", "/", quiet=True)
    0
    >>> list(s.dos("/bin/echo", "foo"))
    ['foo\n']


    '''

    def __init__(self, sim=False, fatal=False, quiet=False):
        self.sim = sim
        self.fatal = fatal
        self.quiet = quiet

    def do(self, *cmd, **options):
        if self.sim:
            print 'Executing:', cmd
            return 0
        if 'quiet' in options or self.quiet:
            out = open(os.devnull, 'w')
        else:
            out = sys.stdout
        if 'fatal' in options:
            fatal = True
        else:
            fatal = self.fatal
        ret = subprocess.call(cmd, stdout=out)
        if fatal and ret != 0:
            sys.exit(ret)
        return ret

    def dos(self, *cmd):
        if self.sim:
            print 'Executing and reading:', cmd
            return
        p = subprocess.Popen(cmd, stdout=subprocess.PIPE)
        for line in p.stdout:
            yield line
        p.wait()


class CWD(object):

    def __init__(self, directory):
        self.npwd = directory

    def __enter__(self):
        self.opwd = os.getcwd()
        os.chdir(self.npwd)

    def __exit__(self, type, value, tb):
        os.chdir(self.opwd)


