# -*- coding: utf-8 -*-
# Copyright (C) 2009 Jan Hülsbergen <jan@afoo.de>
#
# This file is part of cmdlib.
#
# cmdlib is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# cmdlib is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with cmdlib.  If not, see <http://www.gnu.org/licenses/>.

from __future__ import with_statement

import unittest
import types
import os

from cmdlib.system import System, CWD


class SystemTests(unittest.TestCase):

    def test_do(self):
        s = System()
        self.failUnless(s.do('ls', '/', quiet=True) == 0)

    def test_dos(self):
        s = System()
        g = s.dos('/bin/echo', 'foo')
        self.failUnless(isinstance(g, types.GeneratorType))
        self.failUnless(list(g) == ['foo\n'])

    def test_fatal(self):
        s = System(fatal=True, quiet=True)
        self.assertRaises(SystemExit, s.do, 'false')
        s = System(quiet=True)
        self.assertRaises(SystemExit, s.do, 'false', fatal=True)

    def test_CWD(self):
        opwd = os.getcwd()
        with CWD('/tmp'):
            self.failUnless(os.getcwd() == '/tmp')
        self.failUnless(os.getcwd() == opwd)


