# -*- coding: utf-8 -*-
# Copyright (C) 2009 Jan Hülsbergen <jan@afoo.de>
#
# This file is part of cmdlib.
#
# cmdlib is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# cmdlib is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with cmdlib.  If not, see <http://www.gnu.org/licenses/>.

import unittest
import tempfile
import os
import re

from cmdlib import trans


class TransTests(unittest.TestCase):

    def setUp(self):
        f, n = tempfile.mkstemp()
        f = os.fdopen(f, 'w')
        f.write('foo\nbar\nspam\neggs!')
        f.close()
        self.f = n

    def tearDown(self):
        os.unlink(self.f)

    def test_Transformer(self):
        t = trans.Transformer(self.f)
        t.add_trans('!', '?')
        t.add_re_trans(re.compile(r'b(\w)'), r'\1')
        t.add_re_trans(r'o{2}', 'u')
        t.run()
        self.assert_(open(self.f).read() == 'fu\nar\nspam\neggs?')

    def test_simple_trans(self):
        trans.simple_trans(self.f, 'spam', 'SPAM')
        self.assert_(open(self.f).read() == 'foo\nbar\nSPAM\neggs!')

    def test_simple_re_trans(self):
        trans.simple_re_trans(self.f, r'g{2}', 'lve')
        self.assert_(open(self.f).read() == 'foo\nbar\nspam\nelves!')

